@@ -3,13 +3,13 @@ import sys
 from logging.handlers import QueueHandler
 from queue import SimpleQueue
 
-import pytest
-
 import dbus_fast.introspection as intr
+import pytest
 from dbus_fast import DBusError, aio, glib
 from dbus_fast.message import MessageFlag
 from dbus_fast.service import ServiceInterface, method
 from dbus_fast.signature import Variant
+
 from tests.util import check_gi_repository, skip_reason_no_gi
 
 has_gi = check_gi_repository()
@@ -40,7 +40,7 @@ class ExampleInterface(ServiceInterface):
         return [what1, what2, what3]
 
     @method()
-    def GetComplex(self) -> "a{sv}":
+    def GetComplex(self) -> "a{sv}":  # noqa: F722
         """Return complex output."""
         return {"hello": Variant("s", "world")}
 
@@ -117,7 +117,7 @@ async def test_aio_proxy_object():
     finally:
         logger.removeHandler(log_handler)
 
-    assert log_error_queue.empty()
+    assert log_error_queue.empty(), log_error_queue.get_nowait()
 
     bus.disconnect()
     bus2.disconnect()
