@@ -1,5 +1,4 @@
 import pytest
-
 from dbus_fast.aio import MessageBus
 from dbus_fast.service import ServiceInterface, method
 
@@ -11,7 +10,7 @@ async def test_multiple_flags_in_message():
             super().__init__(name)
 
         @method()
-        def Echo(self, what: "s") -> "s":  # noqa: F821
+        def Echo(self, what: "s") -> "s":
             return what
 
     bus = await MessageBus().connect()
