@@ -1,9 +1,9 @@
 import sys
 
 import pytest
-
 from dbus_fast import Message, MessageFlag, MessageType
 from dbus_fast.glib import MessageBus
+
 from tests.util import check_gi_repository, skip_reason_no_gi
 
 has_gi = check_gi_repository()
@@ -14,7 +14,8 @@ if has_gi:
 
 @pytest.mark.skipif(not has_gi, reason=skip_reason_no_gi)
 @pytest.mark.skipif(
-    sys.version_info[:3][1] in (10, 11, 12), reason="segfaults on py3.10,py3.11,py3.12"
+    sys.version_info[:3][1] in (10, 11, 12, 13),
+    reason="segfaults on py3.10,py3.11,py3.12,py3.13",
 )
 def test_standard_interfaces():
     bus = MessageBus().connect_sync()
@@ -57,7 +58,8 @@ def test_standard_interfaces():
 
 @pytest.mark.skipif(not has_gi, reason=skip_reason_no_gi)
 @pytest.mark.skipif(
-    sys.version_info[:3][1] in (10, 11, 12), reason="segfaults on py3.10,py3.11,py3.12"
+    sys.version_info[:3][1] in (10, 11, 12, 13),
+    reason="segfaults on py3.10,py3.11,py3.12,py3.13",
 )
 def test_sending_messages_between_buses():
     bus1 = MessageBus().connect_sync()
@@ -127,7 +129,8 @@ def test_sending_messages_between_buses():
 
 @pytest.mark.skipif(not has_gi, reason=skip_reason_no_gi)
 @pytest.mark.skipif(
-    sys.version_info[:3][1] in (10, 11, 12), reason="segfaults on py3.10,py3.11,py3.12"
+    sys.version_info[:3][1] in (10, 11, 12, 13),
+    reason="segfaults on py3.10,py3.11,py3.12,py3.13",
 )
 def test_sending_signals_between_buses():
     bus1 = MessageBus().connect_sync()
