@@ -5,13 +5,117 @@ from enum import Enum
 from typing import Any
 
 import pytest
-
 from dbus_fast import Message, MessageFlag, MessageType, SignatureTree, Variant
 from dbus_fast._private._cython_compat import FakeCython
-from dbus_fast._private.unmarshaller import Unmarshaller
+from dbus_fast._private.constants import BIG_ENDIAN, LITTLE_ENDIAN
+from dbus_fast._private.unmarshaller import (
+    Unmarshaller,
+    buffer_to_int16,
+    buffer_to_uint16,
+    buffer_to_uint32,
+    is_compiled,
+)
 from dbus_fast.unpack import unpack_variants
 
 
+def test_bytearray_to_uint32_big_end():
+    assert buffer_to_uint32(bytearray(b"\x01\x02\x03\x04"), 0, BIG_ENDIAN) == 16909060
+    assert (
+        buffer_to_uint32(
+            bytearray((0xFFFFFFFF).to_bytes(4, byteorder="big", signed=False)),
+            0,
+            BIG_ENDIAN,
+        )
+        == 0xFFFFFFFF
+    )
+
+
+def test_bytearray_to_uint16_big_end():
+    assert buffer_to_uint16(bytearray(b"\x01\x02"), 0, BIG_ENDIAN) == 258
+    assert (
+        buffer_to_uint16(
+            bytearray((0xFFFF).to_bytes(2, byteorder="big", signed=False)),
+            0,
+            BIG_ENDIAN,
+        )
+        == 0xFFFF
+    )
+
+
+def test_bytearray_to_int16_big_end():
+    assert buffer_to_int16(bytearray(b"\x01\x02"), 0, BIG_ENDIAN) == 258
+    assert (
+        buffer_to_int16(
+            bytearray((32767).to_bytes(2, byteorder="big", signed=True)), 0, BIG_ENDIAN
+        )
+        == 32767
+    )
+
+
+@pytest.mark.skipif(not is_compiled(), reason="requires cython")
+def test_bytearray_to_int16_big_end_signed():
+    assert buffer_to_int16(bytearray(b"\xff\xff"), 0, BIG_ENDIAN) == -1
+    assert (
+        buffer_to_int16(
+            bytearray((-32768).to_bytes(2, byteorder="big", signed=True)),
+            0,
+            BIG_ENDIAN,
+        )
+        == -32768
+    )
+
+
+def test_bytearray_to_uint32_little_end():
+    assert (
+        buffer_to_uint32(bytearray(b"\x01\x02\x03\x04"), 0, LITTLE_ENDIAN) == 67305985
+    )
+    assert (
+        buffer_to_uint32(
+            bytearray((0xFFFFFFFF).to_bytes(4, byteorder="little", signed=False)),
+            0,
+            LITTLE_ENDIAN,
+        )
+        == 0xFFFFFFFF
+    )
+
+
+def test_bytearray_to_uint16_little_end():
+    assert buffer_to_uint16(bytearray(b"\x01\x02"), 0, LITTLE_ENDIAN) == 513
+    assert (
+        buffer_to_uint16(
+            bytearray((0xFFFF).to_bytes(2, byteorder="little", signed=False)),
+            0,
+            LITTLE_ENDIAN,
+        )
+        == 0xFFFF
+    )
+
+
+def test_bytearray_to_int16_little_end():
+    assert buffer_to_int16(bytearray(b"\x01\x02"), 0, LITTLE_ENDIAN) == 513
+    assert (
+        buffer_to_int16(
+            bytearray((32767).to_bytes(2, byteorder="little", signed=True)),
+            0,
+            LITTLE_ENDIAN,
+        )
+        == 32767
+    )
+
+
+@pytest.mark.skipif(not is_compiled(), reason="requires cython")
+def test_bytearray_to_int16_little_end_signed():
+    assert buffer_to_int16(bytearray(b"\xff\xff"), 0, LITTLE_ENDIAN) == -1
+    assert (
+        buffer_to_int16(
+            bytearray((-32768).to_bytes(2, byteorder="little", signed=True)),
+            0,
+            LITTLE_ENDIAN,
+        )
+        == -32768
+    )
+
+
 def print_buf(buf):
     i = 0
     while True:
@@ -89,10 +193,10 @@ def test_marshalling_with_table():
         if buf != data:
             print("message:")
             print(json_dump(item["message"]))
-            print("")
+            print()
             print("mine:")
             print_buf(bytes(buf))
-            print("")
+            print()
             print("theirs:")
             print_buf(data)
 
@@ -129,9 +233,9 @@ def test_unmarshalling_with_table(unmarshall_table):
             "flags",
             "serial",
         ]:
-            assert getattr(unmarshaller.message, attr) == getattr(message, attr), (
-                f"attr doesnt match: {attr}"
-            )
+            assert getattr(unmarshaller.message, attr) == getattr(
+                message, attr
+            ), f"attr doesnt match: {attr}"
 
 
 def test_unmarshall_can_resume():
@@ -536,7 +640,7 @@ def test_unmarshall_large_message():
     }
 
 
-def test_unmarshall_big_endian_message():
+def test_unmarshall_big_end_message():
     """Test we can unmarshall a big endian message."""
     msg = (
         b"B\x01\x00\x01\x00\x00\x00 \x00\x00\x00\x00\x00\x00\x00\x82"
